@@ -5,43 +5,34 @@ import matplotlib.pyplot as plt
 class objearth():
     def __init__(self):
         pass
-    @property
-    def montage(self,img1,img2):
-        self.img1 = img1
-        self.img2 = img2
+    @staticmethod
+    def montage(img1,img2):
         plt.figure(figsize=(15,15))
-        plt.subplot(121),plt.imshow(self.img1, cmap = 'gray')
+        plt.subplot(121),plt.imshow(img1, cmap = 'gray')
         plt.title('Image 1'), plt.xticks([]), plt.yticks([])
-        plt.subplot(122),plt.imshow(self.img2, cmap = 'viridis')
+        plt.subplot(122),plt.imshow(img2, cmap = 'viridis')
         plt.title('Image 2'), plt.xticks([]), plt.yticks([])
         plt.show()
-    @property  
-    def falsecolor(self,Dataset1,Dataset2,Dataset3,bright=10):
-        self.Dataset1 = Dataset1
-        self.Dataset2 = Dataset2 
-        self.Dataset3 = Dataset3
-        self.bright   = bright
-        BAND1    = xarray.where(self.Dataset1==-9999,numpy.nan,self.Dataset1)
+    @staticmethod
+    def falsecolor(Dataset1,Dataset2,Dataset3,bright=10):
+        BAND1    = xarray.where(Dataset1==-9999,numpy.nan,Dataset1)
         band1    = BAND1.to_numpy()/10000*self.bright
-        BAND2    = xarray.where(self.Dataset2==-9999,numpy.nan,self.Dataset2)
+        BAND2    = xarray.where(Dataset2==-9999,numpy.nan,Dataset2)
         band2    = BAND2.to_numpy()/10000*self.bright
-        BAND3    = xarray.where(self.Dataset3==-9999,numpy.nan,self.Dataset3)
+        BAND3    = xarray.where(Dataset3==-9999,numpy.nan,Dataset3)
         band3    = BAND3.to_numpy()/10000*self.bright
         product  = numpy.stack([band1,band2,band3],axis=2)
         return product
-    @property
-    def truecolor(self,Dataset,bright=10):
-        self.Dataset = Dataset
-        self.bright  = bright
-        RED    = xarray.where(self.Dataset.red==-9999,numpy.nan,self.Dataset.red)
+    @staticmethod
+    def truecolor(Dataset,bright=10):
+        RED    = xarray.where(Dataset.red==-9999,numpy.nan,Dataset.red)
         red    = RED.to_numpy()/10000*self.bright
-        BLUE   = xarray.where(self.Dataset.blue==-9999,numpy.nan,self.Dataset.blue)
+        BLUE   = xarray.where(Dataset.blue==-9999,numpy.nan,Dataset.blue)
         blue   = BLUE.to_numpy()/10000*self.bright
-        GREEN  = xarray.where(self.Dataset.green==-9999,numpy.nan,self.Dataset.green)
+        GREEN  = xarray.where(Dataset.green==-9999,numpy.nan,Dataset.green)
         green  = GREEN.to_numpy()/10000*self.bright
         rgb    = numpy.stack([red,green,blue],axis=2)
         return rgb
-    @property
     def clearcloud(self,Dataset0,Dataset1):
         self.Dataset0 = Dataset0
         self.Dataset1 = Dataset1
@@ -58,7 +49,6 @@ class objearth():
         pixel_qa    = xarray.where(mask0,self.Dataset1.pixel_qa,self.Dataset0.pixel_qa)
         # Create DataArray
         return xarray.merge([blue,green,red,nir,pixel_qa])
-    @property
     def plotshow(self,DataArray,lst=True):
         self.DataArray = DataArray
         self.lst = lst
@@ -108,7 +98,6 @@ class objearth():
 
         else:
             print("Nonetype :",type(self.DataArray))
-    @property           
     def percentcloud(self,Dataset):
         self.Dataset = Dataset
         FashCloud = [352,480,944]
@@ -120,7 +109,6 @@ class objearth():
         Allpixel  = int(self.Dataset.pixel_qa.count())
         Cloudpercent = (Cpixel/Allpixel)*100
         print("Percent Cloud : %.4f"%Cloudpercent,"%")
-    @property
     def NDVI(self,DataArray):
         """Normalized Difference vegetation Index"""
         self.DataArray = DataArray
@@ -136,7 +124,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return ndvi3
-    @property
     def NDMI(self,DataArray):
         """Normalized Difference Moisture Index"""
         self.DataArray = DataArray
@@ -152,7 +139,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return ndmi3
-    @property
     def BSI(self,DataArray):
         """Bare Soil Index"""
         self.DataArray = DataArray
@@ -168,7 +154,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return bsi3
-    @property
     def EVI(self,DataArray):
         """Enhanced Vegetation Index"""
         self.DataArray = DataArray
@@ -185,7 +170,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return evi3
-    @property
     def NDWI(self,DataArray):
         """Normalized Difference Water Index"""
         self.DataArray = DataArray
@@ -201,7 +185,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return ndwi3
-    @property
     def NMDI(self,DataArray):
         """Normalized Multi-Band Drought Index"""
         self.DataArray = DataArray
@@ -218,7 +201,6 @@ class objearth():
         plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return nmdi3
-    @property
     def NDDI(self,DataArray):
         """Normalized Difference Drought Index"""
         self.DataArray = DataArray
